@@ -10,17 +10,17 @@ from django.utils.dateparse import parse_date as django_parse_date
 logger = logging.getLogger(__name__)
 
 TRUE_VALUES = (
-    'true',
-    '1',
-    'yes',
+    "true",
+    "1",
+    "yes",
 )
 
 FALSE_VALUES = (
-    'none',
-    'null',
-    'false',
-    '0',
-    'no',
+    "none",
+    "null",
+    "false",
+    "0",
+    "no",
 )
 
 
@@ -35,7 +35,7 @@ def parse_bool(v: str) -> bool:
         return True
     if s in FALSE_VALUES:
         return False
-    raise ValidationError(_("%(value)s is not one of the available choices") % {'value': v})
+    raise ValidationError(_("%(value)s is not one of the available choices") % {"value": v})
 
 
 def parse_datetime(v: str, tz: Any = None) -> datetime:
@@ -52,15 +52,21 @@ def parse_datetime(v: str, tz: Any = None) -> datetime:
         if t is None:
             t_date: Optional[date] = django_parse_date(v)
             if t_date is None:
-                raise ValidationError(_(
-                    "“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format.") % {
-                                          'value': v})
+                raise ValidationError(
+                    _(
+                        "“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format."
+                    )
+                    % {"value": v}
+                )
             t = datetime.combine(t_date, time())
         if tz is None:
             tz = pytz.utc
         return t if t.tzinfo else tz.localize(t)
     except Exception:
-        raise ValidationError(_("“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format.") % {'value': v})
+        raise ValidationError(
+            _("“%(value)s” value has an invalid format. It must be in YYYY-MM-DD HH:MM[:ss[.uuuuuu]][TZ] format.")
+            % {"value": v}
+        )
 
 
 def parse_bool_or_none(v: str) -> Optional[bool]:
